@@ -149,4 +149,7 @@ class ChangeColumnDtypeCodeChunk(CodeChunk):
         if 'pd.to_datetime' in conversion_code:
             code.insert(0, 'import pandas as pd')
 
-        return code
\ No newline at end of file
+        return code
+
+    def get_edited_sheet_indexes(self) -> List[int]:
+        return [self.get_param('sheet_index')]
\ No newline at end of file
