@@ -9,7 +9,7 @@ This file contains helpful functions and classes for testing operations.
 
 import json
 from functools import wraps
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 from mitosheet.code_chunks.code_chunk_utils import get_code_chunks
 from mitosheet.step_performers.graph_steps.plotly_express_graphs import DO_NOT_CHANGE_PAPER_BGCOLOR_DEFAULT, DO_NOT_CHANGE_PLOT_BGCOLOR_DEFAULT, DO_NOT_CHANGE_TITLE_FONT_COLOR_DEFAULT
 from numpy import number
@@ -216,21 +216,17 @@ class MitoWidgetTestWrapper:
             self, 
             how: str,
             sheet_index_one: int, 
-            merge_key_one: ColumnHeader, 
-            selected_columns_one: List[ColumnHeader],
             sheet_index_two: int, 
-            merge_key_two: ColumnHeader,
+            merge_key_columns: List[Tuple[ColumnHeader, ColumnHeader]], 
+            selected_columns_one: List[ColumnHeader],
             selected_columns_two: List[ColumnHeader]
         ) -> bool:
 
-        merge_key_column_id_one = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
-            sheet_index_one,
-            merge_key_one
-        )
-        merge_key_column_id_two = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
-            sheet_index_two,
-            merge_key_two
-        )
+        merge_key_column_ids = list(map(lambda x: [
+            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index_one, x[0]),
+            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index_two, x[1]),
+        ], merge_key_columns))
+
         selected_column_ids_one = [
             self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index_one, column_header)
             for column_header in selected_columns_one
@@ -250,10 +246,9 @@ class MitoWidgetTestWrapper:
                 'params': {
                     'how': how,
                     'sheet_index_one': sheet_index_one,
-                    'merge_key_column_id_one': merge_key_column_id_one,
-                    'selected_column_ids_one': selected_column_ids_one,
                     'sheet_index_two': sheet_index_two,
-                    'merge_key_column_id_two': merge_key_column_id_two,
+                    'merge_key_column_ids': merge_key_column_ids,
+                    'selected_column_ids_one': selected_column_ids_one,
                     'selected_column_ids_two': selected_column_ids_two
                 }
             }
@@ -356,6 +351,63 @@ class MitoWidgetTestWrapper:
             }
         )
     
+
+    @check_transpiled_code_after_call
+    def transpose(
+            self, 
+            sheet_index: int,
+        ) -> bool:
+
+        
+
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'transpose_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'sheet_index': sheet_index,
+                    
+                }
+            }
+        )
+    
+
+    @check_transpiled_code_after_call
+    def melt(
+            self, 
+            sheet_index: int,
+            id_var_column_headers: List[ColumnHeader],
+            value_var_column_headers: List[ColumnHeader],
+        ) -> bool:
+
+        id_var_column_ids = [
+            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index, column_header)
+            for column_header in id_var_column_headers
+        ]
+        value_var_column_ids = [
+            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index, column_header)
+            for column_header in value_var_column_headers
+        ]
+
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'melt_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'sheet_index': sheet_index,
+                    'id_var_column_ids': id_var_column_ids,
+                    'value_var_column_ids': value_var_column_ids,
+                    
+                }
+            }
+        )
+    
 # AUTOGENERATED LINE: TEST (DO NOT DELETE)
 
     @check_transpiled_code_after_call
